@@ -258,6 +258,11 @@ class OmegaParserTestMixin(object):
 		self.assertEqual(self._parse(r"'\r\n\t\\'", 'atom'),
 				('item', "\r\n\t\\"))
 
+		# Strings cannot contain unescaped newlines.
+		self.assertRaises(ParseError, self._parse, "'\n'", 'atom')
+		self.assertEqual(self._parse("'hello\\\nworld'", 'atom'),
+				('item', "helloworld"))
+
 	def test_atom_token(self):
 		# A double-quoted string is compiled as an invocation of 'token'. Note
 		# that because the compiler assumes invocations come from hostExprs, it
@@ -285,6 +290,11 @@ class OmegaParserTestMixin(object):
 		self.assertEqual(self._parse(r'"\r\n\t\\"', 'atom'),
 				('invocation', 'token', r'"\r\n\t\\"'))
 
+		# Tokens cannot contain unescaped newlines.
+		self.assertRaises(ParseError, self._parse, '"\n"', 'atom')
+		self.assertEqual(self._parse('"hello\\\nworld"', 'atom'),
+				('invocation', 'token', '"hello\\\nworld"'))
+
 	def test_atom_invocation(self):
 		# Any random identifier gets parsed as an invocation of a rule with
 		# that name.
